<?php

namespace B2buy\MasterService\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use B2buy\MasterService\Actions\MasterServiceAction;
use B2buy\MasterService\Http\Requests\MasterServiceActionRequest;
use B2buy\MasterService\Http\Resources\MasterServiceResource;
use B2buy\MasterService\Models\MasterService;

/**
 * Admin web controller class.
 */
class MasterServiceActionController extends BaseController
{

    /**
     * Action controller function for master_service.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MasterServiceActionRequest $request, MasterService $master_service, $action)
    {
        try {
            $request = $request->all();
            $master_service = MasterServiceAction::run($action, $master_service, $request);

            $data = new MasterServiceResource($master_service);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('master_service::master_service.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master_service/master_service/' . $master_service->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_service/master_service/' . $master_service->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
