<?php

namespace B2buy\MasterService\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use B2buy\MasterService\Http\Resources\MasterServiceResource;
use B2buy\MasterService\Http\Resources\MasterServicesCollection;
use B2buy\MasterService\Scopes\MasterServicePublicScope;
use B2buy\MasterService\Models\MasterService;

class MasterServicePublicController extends BaseController
{

    /**
     * Show master_service's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = MasterService::pushScope(new RequestScope())
            ->pushScope(new MasterServicePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $master_services = new MasterServicesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('master_service::master_service.names'))
            ->view('master_service::public.master_service.index')
            ->data(compact('master_services', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show master_service.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = MasterService::findBySlug($slug);
        $data = new MasterServiceResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('master_service::master_service.name'))
            ->view('master_service::public.master_service.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
