<?php

namespace B2buy\MasterService\Http\Controllers;

use Exception;
use B2buy\MasterService\Actions\MasterServiceWorkflow;
use B2buy\MasterService\Http\Requests\MasterServiceWorkflowRequest;
use B2buy\MasterService\Http\Resources\MasterServiceResource;
use B2buy\MasterService\Models\MasterService;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class MasterServiceWorkflowController extends BaseController
{
    /**
     * Action controller function for master_service.
     *
     * @param Model $master_service
     * @param action next action for the master_service.
     *
     * @return Response
     */
    public function __invoke(MasterServiceWorkflowRequest $request, MasterService $master_service, $trasition)
    {
        try {
            $request = $request->all();
            $master_service = MasterServiceWorkflow::run($trasition, $master_service, $request);
            $data = new MasterServiceResource($master_service);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master_service::master_service.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master_service/master_service/' . $master_service->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master_service/master_service/' . $master_service->getRouteKey()))
                ->redirect();
        }
    }
}
