<?php

namespace B2buy\MasterService\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use B2buy\MasterService\Events\MasterServiceAction as MasterServiceActionEvent;
use B2buy\MasterService\Notifications\MasterServiceAction as MasterServiceActionNotification;
use Litepie\Actions\Concerns\AsAction;

class MasterServiceAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the MasterServiceActionEvent.
     *
     * @param   MasterServiceActionEvent  $event
     * @return mixed
     */
    public function handle(MasterServiceActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $master_service.
     *
     * @param   MasterServiceActionEvent  $event
     * @return void
     */
    public function create(MasterServiceActionEvent $event)
    {
        $client = $event->$master_service->client;
        Notification::send($client, new MasterServiceActionNotification($event));
    }

    /**
     * Handle the MasterServiceActionEvent as a listener.
     *
     * @param   MasterServiceActionEvent  $event
     * @return mixed
     */
    public function asListener(MasterServiceActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   MasterServiceActionEvent  $event
     * @return bool
     */
    private function isAllowed(MasterServiceActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
