<?php

namespace B2buy\MasterService\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use B2buy\MasterService\Events\MasterServiceWorkflow as MasterServiceWorkflowEvent;
use B2buy\MasterService\Notifications\MasterServiceWorkflow as MasterServiceWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class MasterServiceWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(MasterServiceWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $master_service is submitted.
     *
     * @param MasterServiceWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(MasterServiceWorkflowEvent $event)
    {
        $client = $event->$master_service->client;
        Notification::send($client, new MasterServiceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $master_service is published.
     *
     * @param MasterServiceWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(MasterServiceWorkflowEvent $event)
    {
        $client = $event->$master_service->client;
        Notification::send($client, new MasterServiceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $master_service is approved.
     *
     * @param MasterServiceWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(MasterServiceWorkflowEvent $event)
    {
        $client = $event->$master_service->client;
        Notification::send($client, new MasterServiceWorkflowNotification($event));
    }

    /**
     * Handles the $master_service workflow event as a listener.
     *
     * @param MasterServiceWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(MasterServiceWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
