<?php
namespace B2buy\MasterService\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use B2buy\MasterService\Events\MasterServiceAction as MasterServiceActionEvent;
use B2buy\MasterService\Models\MasterService;

class MasterServiceAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $master_service;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param MasterServiceActionEvent $master_service
     * @param string $action
     */
    public function __construct(MasterServiceActionEvent $master_service, string $action)
    {
        $this->action = $action;
        $this->master_service = $master_service;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('MasterService Approved - ' . config('app.name'))
            ->view('master_service::master_service.email.action', ['data' => $this->master_service]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
