<?php

namespace B2buy\MasterService\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use B2buy\MasterService\Models\MasterService;

class MasterServicePolicy
{

    use MasterServiceAction;
    use MasterServiceWorkflow;

    /**
     * Determine if the given user can view the master_service.
     *
     * @param UserPolicyInterface $authUser
     * @param MasterService $master_service
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, MasterService $master_service)
    {
        if ($authUser->canDo('master_service.master_service.view') && $authUser->isAdmin()) {
            return true;
        }

        return $master_service->user_id == user_id() && $master_service->user_type == user_type();
    }

    /**
     * Determine if the given user can create a master_service.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('master_service.master_service.create');
    }

    /**
     * Determine if the given user can update the given master_service.
     *
     * @param UserPolicyInterface $authUser
     * @param MasterService $master_service
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, MasterService $master_service)
    {
        if ($authUser->canDo('master_service.master_service.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $master_service->user_id == user_id() && $master_service->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given master_service.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, MasterService $master_service)
    {
        return $master_service->user_id == user_id() && $master_service->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given master_service.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, MasterService $master_service)
    {
        if ($authUser->canDo('master_service.master_service.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given master_service.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, MasterService $master_service)
    {
        if ($authUser->canDo('master_service.master_service.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
