<?php

namespace B2buy\MasterService\Providers;

use Illuminate\Support\ServiceProvider;
use B2buy\MasterService\MasterServices;

class MasterServiceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'master_service');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'master_service');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\B2buy\MasterService\Providers\AuthServiceProvider::class);
        $this->app->register(\B2buy\MasterService\Providers\RouteServiceProvider::class);
        $this->app->register(\B2buy\MasterService\Providers\ActionServiceProvider::class);
        $this->app->register(\B2buy\MasterService\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('b2buy.master_service', function($app)
        {
            return $this->app->make(MasterService::class);
        });
    }

    /**
     * Merges user's and master_service's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.master_service'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/master_service.php', 'b2buy.master_service.master_service'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.master_service'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('b2buy/master_service')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/master_service')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/master_service')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
